@@ -519,7 +519,7 @@ class BucketDeployment(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deployedBucket")
     def deployed_bucket(self) -> aws_cdk.aws_s3.IBucket:
         '''The bucket after the deployment.
@@ -654,7 +654,7 @@ class BucketDeploymentProps:
         if isinstance(metadata, dict):
             metadata = UserDefinedObjectMetadata(**metadata)
         if isinstance(vpc_subnets, dict):
-            vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+            vpc_subnets = SubnetSelection(**vpc_subnets)
         if __debug__:
             type_hints = typing.get_type_hints(BucketDeploymentProps.__init__)
             check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
@@ -1107,7 +1107,7 @@ class CacheControl(
         )
     '''
 
-    @jsii.member(jsii_name="fromString") # type: ignore[misc]
+    @jsii.member(jsii_name="fromString")
     @builtins.classmethod
     def from_string(cls, s: builtins.str) -> "CacheControl":
         '''Constructs a custom cache control key from the literal value.
@@ -1119,7 +1119,7 @@ class CacheControl(
             check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "fromString", [s]))
 
-    @jsii.member(jsii_name="maxAge") # type: ignore[misc]
+    @jsii.member(jsii_name="maxAge")
     @builtins.classmethod
     def max_age(cls, t: aws_cdk.core.Duration) -> "CacheControl":
         '''Sets 'max-age='.
@@ -1131,43 +1131,43 @@ class CacheControl(
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "maxAge", [t]))
 
-    @jsii.member(jsii_name="mustRevalidate") # type: ignore[misc]
+    @jsii.member(jsii_name="mustRevalidate")
     @builtins.classmethod
     def must_revalidate(cls) -> "CacheControl":
         '''Sets 'must-revalidate'.'''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "mustRevalidate", []))
 
-    @jsii.member(jsii_name="noCache") # type: ignore[misc]
+    @jsii.member(jsii_name="noCache")
     @builtins.classmethod
     def no_cache(cls) -> "CacheControl":
         '''Sets 'no-cache'.'''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "noCache", []))
 
-    @jsii.member(jsii_name="noTransform") # type: ignore[misc]
+    @jsii.member(jsii_name="noTransform")
     @builtins.classmethod
     def no_transform(cls) -> "CacheControl":
         '''Sets 'no-transform'.'''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "noTransform", []))
 
-    @jsii.member(jsii_name="proxyRevalidate") # type: ignore[misc]
+    @jsii.member(jsii_name="proxyRevalidate")
     @builtins.classmethod
     def proxy_revalidate(cls) -> "CacheControl":
         '''Sets 'proxy-revalidate'.'''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "proxyRevalidate", []))
 
-    @jsii.member(jsii_name="setPrivate") # type: ignore[misc]
+    @jsii.member(jsii_name="setPrivate")
     @builtins.classmethod
     def set_private(cls) -> "CacheControl":
         '''Sets 'private'.'''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "setPrivate", []))
 
-    @jsii.member(jsii_name="setPublic") # type: ignore[misc]
+    @jsii.member(jsii_name="setPublic")
     @builtins.classmethod
     def set_public(cls) -> "CacheControl":
         '''Sets 'public'.'''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "setPublic", []))
 
-    @jsii.member(jsii_name="sMaxAge") # type: ignore[misc]
+    @jsii.member(jsii_name="sMaxAge")
     @builtins.classmethod
     def s_max_age(cls, t: aws_cdk.core.Duration) -> "CacheControl":
         '''Sets 's-maxage='.
@@ -1179,7 +1179,7 @@ class CacheControl(
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "sMaxAge", [t]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Any:
         '''The raw cache control setting.'''
@@ -1259,7 +1259,7 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
         expires = s3_deployment.Expires.after(cdk.Duration.minutes(30))
     '''
 
-    @jsii.member(jsii_name="after") # type: ignore[misc]
+    @jsii.member(jsii_name="after")
     @builtins.classmethod
     def after(cls, t: aws_cdk.core.Duration) -> "Expires":
         '''(deprecated) Expire once the specified duration has passed since deployment time.
@@ -1273,7 +1273,7 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "after", [t]))
 
-    @jsii.member(jsii_name="atDate") # type: ignore[misc]
+    @jsii.member(jsii_name="atDate")
     @builtins.classmethod
     def at_date(cls, d: datetime.datetime) -> "Expires":
         '''(deprecated) Expire at the specified date.
@@ -1287,7 +1287,7 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
             check_type(argname="argument d", value=d, expected_type=type_hints["d"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atDate", [d]))
 
-    @jsii.member(jsii_name="atTimestamp") # type: ignore[misc]
+    @jsii.member(jsii_name="atTimestamp")
     @builtins.classmethod
     def at_timestamp(cls, t: jsii.Number) -> "Expires":
         '''(deprecated) Expire at the specified timestamp.
@@ -1301,7 +1301,7 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atTimestamp", [t]))
 
-    @jsii.member(jsii_name="fromString") # type: ignore[misc]
+    @jsii.member(jsii_name="fromString")
     @builtins.classmethod
     def from_string(cls, s: builtins.str) -> "Expires":
         '''(deprecated) Create an expiration date from a raw date string.
@@ -1315,7 +1315,7 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
             check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("Expires", jsii.sinvoke(cls, "fromString", [s]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Any:
         '''(deprecated) The raw expiration date expression.
@@ -1440,7 +1440,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         })
     '''
 
-    @jsii.member(jsii_name="asset") # type: ignore[misc]
+    @jsii.member(jsii_name="asset")
     @builtins.classmethod
     def asset(
         cls,
@@ -1489,7 +1489,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
 
         return typing.cast(ISource, jsii.sinvoke(cls, "asset", [path, options]))
 
-    @jsii.member(jsii_name="bucket") # type: ignore[misc]
+    @jsii.member(jsii_name="bucket")
     @builtins.classmethod
     def bucket(
         cls,
@@ -1509,7 +1509,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
             check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
         return typing.cast(ISource, jsii.sinvoke(cls, "bucket", [bucket, zip_object_key]))
 
-    @jsii.member(jsii_name="data") # type: ignore[misc]
+    @jsii.member(jsii_name="data")
     @builtins.classmethod
     def data(cls, object_key: builtins.str, data: builtins.str) -> ISource:
         '''Deploys an object with the specified string contents into the bucket.
@@ -1529,7 +1529,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         return typing.cast(ISource, jsii.sinvoke(cls, "data", [object_key, data]))
 
-    @jsii.member(jsii_name="jsonData") # type: ignore[misc]
+    @jsii.member(jsii_name="jsonData")
     @builtins.classmethod
     def json_data(cls, object_key: builtins.str, obj: typing.Any) -> ISource:
         '''Deploys an object with the specified JSON object into the bucket.
